sdv.constraints.ScalarInequality
================================

.. currentmodule:: sdv.constraints

.. autoclass:: ScalarInequality

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ScalarInequality.__init__
      ~ScalarInequality.filter_valid
      ~ScalarInequality.fit
      ~ScalarInequality.fit_transform
      ~ScalarInequality.from_dict
      ~ScalarInequality.is_valid
      ~ScalarInequality.reverse_transform
      ~ScalarInequality.to_dict
      ~ScalarInequality.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScalarInequality.constraint_columns
   
   